pub struct AuthorizationServerMetadata {Show 13 fields
pub issuer: String,
pub authorization_endpoint: String,
pub token_endpoint: String,
pub registration_endpoint: Option<String>,
pub scopes_supported: Option<Vec<String>>,
pub response_types_supported: Vec<String>,
pub response_modes_supported: Option<Vec<String>>,
pub grant_types_supported: Option<Vec<String>>,
pub token_endpoint_auth_methods_supported: Option<Vec<String>>,
pub code_challenge_methods_supported: Option<Vec<String>>,
pub revocation_endpoint: Option<String>,
pub introspection_endpoint: Option<String>,
pub additional: HashMap<String, Value>,
}Expand description
Authorization Server Metadata as defined in RFC 8414
Fields
issuer: StringThe authorization server’s issuer identifier
URL of the authorization endpoint
token_endpoint: StringURL of the token endpoint
registration_endpoint: Option<String>URL of the registration endpoint for dynamic client registration
scopes_supported: Option<Vec<String>>JSON array containing a list of scopes
response_types_supported: Vec<String>JSON array containing a list of response types
response_modes_supported: Option<Vec<String>>JSON array containing a list of response modes
grant_types_supported: Option<Vec<String>>JSON array containing a list of grant types
token_endpoint_auth_methods_supported: Option<Vec<String>>JSON array containing a list of token endpoint authentication methods
code_challenge_methods_supported: Option<Vec<String>>JSON array containing a list of PKCE code challenge methods
revocation_endpoint: Option<String>URL of the revocation endpoint
introspection_endpoint: Option<String>URL of the introspection endpoint
additional: HashMap<String, Value>Additional metadata fields